@@ -1,22 +1,7 @@
 /*
- * Copyright 2020  Michail Vourlakos <mvourlakos@gmail.com>
- *
- * This file is part of Latte-Dock
- *
- * Latte-Dock is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * Latte-Dock is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- */
+    SPDX-FileCopyrightText: 2020 Michail Vourlakos <mvourlakos@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "tablayoutshandler.h"
 
@@ -326,6 +311,11 @@ Ui::SettingsDialog *TabLayouts::ui() const
     return m_ui;
 }
 
+Controller::Layouts *TabLayouts::layoutsController() const
+{
+    return m_layoutsController;
+}
+
 bool TabLayouts::hasChangedData() const
 {
     return m_layoutsController->hasChangedData();
@@ -601,6 +591,12 @@ void TabLayouts::exportLayoutAsTemplate()
     Data::Layout exp_layout = o_layout;
     exp_layout.name = c_layout.name;
 
+    CentralLayout *central =  m_layoutsController->centralLayout(c_layout.id);
+
+    if (central->isActive()) {
+        central->syncToLayoutFile();
+    }
+
     Dialog::ExportTemplateDialog *exportDlg = new Dialog::ExportTemplateDialog(m_parentDialog, exp_layout);
     exportDlg->exec();
 }
