@@ -1,20 +1,6 @@
 /*
-*  Copyright 2019  Michail Vourlakos <mvourlakos@gmail.com>
-*
-*  This file is part of Latte-Dock
-*
-*  Latte-Dock is free software; you can redistribute it and/or
-*  modify it under the terms of the GNU General Public License as
-*  published by the Free Software Foundation; either version 2 of
-*  the License, or (at your option) any later version.
-*
-*  Latte-Dock is distributed in the hope that it will be useful,
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*  GNU General Public License for more details.
-*
-*  You should have received a copy of the GNU General Public License
-*  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-FileCopyrightText: 2019 Michail Vourlakos <mvourlakos@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "containmentinterface.h"
@@ -28,6 +14,7 @@
 
 // Qt
 #include <QDebug>
+#include <QLatin1String>
 
 // Plasma
 #include <Plasma/Applet>
@@ -83,9 +70,9 @@ void ContainmentInterface::identifyShortcutsHost()
         const auto &childItems = graphicItem->childItems();
 
         for (QQuickItem *item : childItems) {
-            if (item->objectName() == "containmentViewLayout" ) {
+            if (item->objectName() == QLatin1String("containmentViewLayout")) {
                 for (QQuickItem *subitem : item->childItems()) {
-                    if (subitem->objectName() == "PositionShortcutsAbilityHost") {
+                    if (subitem->objectName() == QLatin1String("PositionShortcutsAbilityHost")) {
                         m_shortcutsHost = subitem;
                         identifyMethods();
                         return;
@@ -212,7 +199,7 @@ bool ContainmentInterface::updateBadgeForLatteTask(const QString identifier, con
     for (auto *applet : applets) {
         KPluginMetaData meta = applet->kPackage().metadata();
 
-        if (meta.pluginId() == "org.kde.latte.plasmoid") {
+        if (meta.pluginId() == QLatin1String("org.kde.latte.plasmoid")) {
 
             if (QQuickItem *appletInterface = applet->property("_plasma_graphicObject").value<QQuickItem *>()) {
                 const auto &childItems = appletInterface->childItems();
@@ -642,7 +629,7 @@ void ContainmentInterface::onAppletAdded(Plasma::Applet *applet)
         KPluginMetaData meta = applet->kPackage().metadata();
         const auto &provides = KPluginMetaData::readStringList(meta.rawData(), QStringLiteral("X-Plasma-Provides"));
 
-        if (meta.pluginId() == "org.kde.latte.plasmoid") {
+        if (meta.pluginId() == QLatin1String("org.kde.latte.plasmoid")) {
             //! populate latte tasks applet
             m_latteTasksModel->addTask(ai);
         } else if (provides.contains(QLatin1String("org.kde.plasma.multitasking"))) {
