@@ -1,20 +1,6 @@
 /*
-*  Copyright 2018  Michail Vourlakos <mvourlakos@gmail.com>
-*
-*  This file is part of Latte-Dock
-*
-*  Latte-Dock is free software; you can redistribute it and/or
-*  modify it under the terms of the GNU General Public License as
-*  published by the Free Software Foundation; either version 2 of
-*  the License, or (at your option) any later version.
-*
-*  Latte-Dock is distributed in the hope that it will be useful,
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*  GNU General Public License for more details.
-*
-*  You should have received a copy of the GNU General Public License
-*  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-FileCopyrightText: 2018 Michail Vourlakos <mvourlakos@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "positioner.h"
@@ -162,6 +148,13 @@ void Positioner::init()
     connect(m_view, &Latte::View::behaveAsPlasmaPanelChanged, this, &Positioner::syncGeometry);
     connect(m_view, &Latte::View::maxThicknessChanged, this, &Positioner::syncGeometry);
 
+    connect(m_view, &Latte::View::behaveAsPlasmaPanelChanged,  this, [&]() {
+        if (!m_view->behaveAsPlasmaPanel() && m_slideOffset != 0) {
+            m_slideOffset = 0;
+            syncGeometry();
+        }
+    });
+
     connect(m_view, &Latte::View::offsetChanged, this, [&]() {
         updatePosition(m_lastAvailableScreenRect);
     });
@@ -247,6 +240,8 @@ void Positioner::updateWaylandId()
 
         m_trackedWindowId = newId;
         m_corona->wm()->registerIgnoredWindow(m_trackedWindowId);
+
+        emit winIdChanged();
     }
 }
 
@@ -351,6 +346,11 @@ void Positioner::onCurrentLayoutIsSwitching(const QString &layoutName)
     slideOutDuringExit();
 }
 
+void Positioner::setWindowOnActivities(const Latte::WindowSystem::WindowId &wid, const QStringList &activities)
+{
+    m_corona->wm()->setWindowOnActivities(wid, activities);
+}
+
 void Positioner::syncLatteViews()
 {
     if (m_view->layout()) {
